@@ -16,12 +16,12 @@
 #include "kmkernel.h"
 #include "kmreadermainwin.h"
 #include "settings/kmailsettings.h"
-#include <AkonadiCore/ItemFetchScope>
-#include <AkonadiCore/itemfetchjob.h>
+#include <Akonadi/ItemFetchJob>
+#include <Akonadi/ItemFetchScope>
+#include <KContacts/Addressee>
 #include <KIdentityManagement/Identity>
 #include <MailCommon/FolderSettings>
 #include <MailCommon/MailUtil>
-#include <kcontacts/addressee.h>
 
 #include <QGpgME/Protocol>
 
