@@ -1,16 +1,16 @@
 /*
-   SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "createforwardmessagejob.h"
 #include "../util.h"
-#include "composer.h"
 #include "editor/kmcomposerwin.h"
 #include "kmkernel.h"
 #include <KEmailAddress>
 #include <MailCommon/MailUtil>
+#include <MessageComposer/Composer>
 
 CreateForwardMessageJob::CreateForwardMessageJob(QObject *parent)
     : QObject(parent)
