@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -18,7 +18,7 @@
 #include <Akonadi/AgentTypeDialog>
 #include <Akonadi/CollectionFetchJob>
 #include <Akonadi/CollectionFetchScope>
-#include <Akonadi/Contact/ContactEditorDialog>
+#include <Akonadi/ContactEditorDialog>
 
 #include <KLocalizedString>
 #include <KMessageBox>
