@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -7,11 +7,11 @@
 #include "createreplymessagejob.h"
 
 #include "../util.h"
-#include "composer.h"
 #include "editor/kmcomposerwin.h"
 #include "kmkernel.h"
 #include <KEmailAddress>
 #include <MailCommon/MailUtil>
+#include <MessageComposer/Composer>
 
 CreateReplyMessageJob::CreateReplyMessageJob(QObject *parent)
     : QObject(parent)
