@@ -15,6 +15,7 @@ class KMMainWidget;
 class KToggleAction;
 class QLabel;
 class KHamburgerMenu;
+class KToggleFullScreenAction;
 namespace KPIM
 {
 class ProgressStatusBarWidget;
@@ -32,7 +33,6 @@ public:
 
     /// Same as KMMainWin::restore(), except that it also restores the docked state,
     /// which we have saved in saveProperties().
-    /// TODO: KDE5: Move to kdelibs, see http://reviewboard.kde.org/r/504
     bool restoreDockedState(int number);
 
     void showAndActivateWindow();
@@ -56,11 +56,12 @@ private:
     void slotToggleMenubar(bool dontShowWarning);
     void updateHamburgerMenu();
     void slotShortcutSaved();
-    KPIM::ProgressStatusBarWidget *mProgressBar = nullptr;
+    void slotFullScreen(bool t);
+    KPIM::ProgressStatusBarWidget *const mProgressBar;
     KMMainWidget *mKMMainWidget = nullptr;
     KToggleAction *mShowMenuBarAction = nullptr;
-    QLabel *mMessageLabel = nullptr;
+    QLabel *const mMessageLabel;
     KHamburgerMenu *mHamburgerMenu = nullptr;
+    KToggleFullScreenAction *mShowFullScreenAction = nullptr;
     bool mReallyClose = false;
 };
-
