@@ -10,8 +10,7 @@
 
 #include "kmail_options.h"
 #include "kmkernel.h" //control center
-#include <kcoreaddons_version.h>
-#if KCOREADDONS_VERSION < QT_VERSION_CHECK(6, 0, 0)
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 #include "kmmigrateapplication.h"
 #endif
 
@@ -21,6 +20,8 @@
 #include "aboutdata.h"
 
 #include <KCrash>
+#include <KStartupInfo>
+#include <KWindowSystem>
 #include <QApplication>
 #include <QDir>
 #include <QSessionManager>
@@ -68,6 +69,12 @@ void KMailApplication::setEventLoopReached()
 
 int KMailApplication::newInstance(const QByteArray &startupId, const QStringList &arguments, const QString &workingDirectory)
 {
+    if (KWindowSystem::isPlatformX11()) {
+        KStartupInfo::setNewStartupId(kmkernel->mainWin()->windowHandle(), startupId);
+    } else if (KWindowSystem::isPlatformWayland()) {
+        KWindowSystem::setCurrentXdgActivationToken(QString::fromUtf8(startupId));
+    }
+
     if (!kmkernel->firstInstance() && !arguments.isEmpty()) {
         // if we're going to create a new window (viewer or composer),
         // don't bring the mainwindow onto the current desktop
@@ -100,6 +107,9 @@ int KMailApplication::activate(const QStringList &args, const QString &workingDi
         kmkernel->handleCommandLine(true, args, workingDir);
     }
     kmkernel->setFirstInstance(false);
+
+    KWindowSystem::activateWindow(kmkernel->mainWin()->windowHandle());
+
     return 0;
 }
 
@@ -113,8 +123,10 @@ void KMailApplication::delayedInstanceCreation(const QStringList &args, const QS
 int main(int argc, char *argv[])
 {
     QCoreApplication::setAttribute(Qt::AA_ShareOpenGLContexts, true);
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     QCoreApplication::setAttribute(Qt::AA_EnableHighDpiScaling, true);
     QCoreApplication::setAttribute(Qt::AA_UseHighDpiPixmaps, true);
+#endif
     // Necessary for "cid" support in kmail.
     QWebEngineUrlScheme cidScheme("cid");
     cidScheme.setFlags(QWebEngineUrlScheme::SecureScheme | QWebEngineUrlScheme::ContentSecurityPolicyIgnored);
@@ -138,9 +150,8 @@ int main(int argc, char *argv[])
 
 #ifdef WITH_KUSERFEEDBACK
     if (cmdArgs->isSet(QStringLiteral("feedback"))) {
-        auto userFeedback = new KMailUserFeedbackProvider(nullptr);
-        QTextStream(stdout) << userFeedback->describeDataSources() << '\n';
-        delete userFeedback;
+        KMailUserFeedbackProvider userFeedback(nullptr);
+        QTextStream(stdout) << userFeedback.describeDataSources() << '\n';
         return 0;
     }
 #endif
@@ -149,7 +160,7 @@ int main(int argc, char *argv[])
         qCDebug(KMAIL_LOG) << "Another instance of KMail already running";
         return 0;
     }
-#if KCOREADDONS_VERSION < QT_VERSION_CHECK(6, 0, 0)
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     KMMigrateApplication migrate;
     migrate.migrate();
 #endif
